<?php

namespace Flat101\Megamenu\Console\Command;

use Flat101\Megamenu\Model\Menu;
use Flat101\Megamenu\Model\ResourceModel\MenuItems\CollectionFactory;
use Magento\Framework\Exception\NoSuchEntityException;
use Magento\Framework\UrlInterface;
use Magento\Store\Model\StoreManagerInterface;
use Symfony\Component\Console\Command\Command;
use Symfony\Component\Console\Input\InputInterface;
use Symfony\Component\Console\Input\InputOption;
use Symfony\Component\Console\Output\OutputInterface;

class CleanUrl extends Command
{
    /**
     * @var StoreManagerInterface
     */
    protected $storeManager;

    /**
     * @var Menu
     */
    protected $menu;

    /**
     * @var Collection
     */
    protected $menuItemsCollection;

    /**
     * @param StoreManagerInterface $storeManager
     * @param Menu $menu
     * @param CollectionFactory $menuItemsCollection
     */
    public function __construct(
        StoreManagerInterface $storeManager,
        Menu $menu,
        CollectionFactory $menuItemsCollection
    ) {
        parent::__construct();
        $this->storeManager = $storeManager;
        $this->menu = $menu;
        $this->menuItemsCollection = $menuItemsCollection;
    }

    /**
     * @inheritDoc
     */
    protected function configure()
    {
        $this->setName('flat101:megamenu:clean')
            ->setDescription('Clean base URL from item urls')
            ->addOption(
                'base',
                null,
                InputOption::VALUE_OPTIONAL,
                'Base URL to remove. It uses the Domain base url as default.'
            );
    }

    /**
     * @param InputInterface $input
     * @param OutputInterface $output
     * @return int|void|null
     * @throws NoSuchEntityException
     */
    public function execute(InputInterface $input, OutputInterface $output)
    {
        $baseUrl = $input->getOption('base');

        if (empty($baseUrl)) {
            $baseUrl = $this->storeManager->getStore()->getBaseUrl(UrlInterface::URL_TYPE_WEB);
        }

        $baseUrl = rtrim($baseUrl,'/');
        $output->writeln('URL to replace: ' . $baseUrl);

        $collection = $this->menuItemsCollection->create();

        foreach ($collection as $item) {
            $data = $item->getData();
            $data['custom_link'] = str_replace($baseUrl, "", $data['custom_link']);

            if (isset($data['content'])) {
                $menu_content = unserialize($data['content']);

                $new_arr = [];
                foreach ($menu_content as $key => $value) {
                    $new_arr[$key] = str_replace($baseUrl, "", $value);
                }
                $data['content'] = serialize($new_arr);
            }

            $item->setData($data);
            $item->Save();
        }

        $output->writeln('Work done!!');
    }
}
