<?php

namespace Flat101\Megamenu\Controller\Adminhtml\Category;

use Magento\Store\Model\ScopeInterface;
use Magento\Framework\Controller\Result\JsonFactory;

class Create extends \Magento\Backend\App\Action
{

    /**
     * @var \Flat101\Megamenu\Model\MenuItemsFactory
     */
    protected $modelMenuFactory;

    /**
     * @var JsonFactory
     */
    protected $resultJsonFactory;

    /**
     * @var \Magento\Store\Model\StoreManagerInterface
     */
    protected $storeManager;

    /**
     * @var \Magento\Framework\App\Config\Storage\WriterInterface
     */
    protected $config;

    /**
     * Create constructor.
     * @param \Magento\Backend\App\Action\Context $context
     * @param \Flat101\Megamenu\Model\MenuItemsFactory $modelMenuFactory
     * @param JsonFactory $resultJsonFactory
     * @param \Magento\Framework\App\Config\Storage\WriterInterface $config
     * @param \Magento\Store\Model\StoreManagerInterface $storeManager
     */
    public function __construct(
        \Magento\Backend\App\Action\Context $context,
        \Flat101\Megamenu\Model\MenuItemsFactory $modelMenuFactory,
        JsonFactory $resultJsonFactory,
        \Magento\Framework\App\Config\Storage\WriterInterface $config,
        \Magento\Store\Model\StoreManagerInterface $storeManager
    ) {
        parent::__construct($context);
        $this->resultJsonFactory = $resultJsonFactory;
        $this->storeManager = $storeManager;
        $this->modelMenuFactory = $modelMenuFactory;
        $this->config = $config;
    }

    /**
     * @return \Magento\Framework\App\ResponseInterface|\Magento\Framework\Controller\Result\Json|\Magento\Framework\Controller\ResultInterface
     */
    public function execute()
    {
        $resultEcho = $this->resultJsonFactory->create();

        $params = $this->getRequest()->getParams();
        $menu = $this->modelMenuFactory->create();
        $menu = $menu->getCollection()
            ->addFieldToSelect('*');
        $menuId = $menu->getData('menu_id');

        if ($menuId) {
            $menuId = $menuId[0]['menu_id'];
        } else {
            $menuId = '';
        }

        $storeId = $params['store_id'];

        if (!$storeId) {
            $storeId = 0;
            $scopeId = 'default';
        } else {
            $scopeId = ScopeInterface::SCOPE_STORES;
        }

        if ($params['menu']) {
            $this->config->save('megamenu/tree/data', $params['menu'], $scopeId, $storeId);
        }

        $result['empty'] = true;
        $result['mega_menu_id'] = $menuId;

        if ($params['type'] == 'delete') {
            $id = explode('_', $params['node_id']);
            $menuCollection = $this->modelMenuFactory->create();
            $menuCollection = $menuCollection->getCollection()
                ->addFieldToSelect('*')
                ->addFieldToFilter('menu_id', $id[1])
                ->addFieldToFilter('store_id', $params['store_id'])
                ->getLastItem();

            $menuCollection->delete();
        }

        return $resultEcho->setData($result);
    }
}
